@@ -216,7 +216,21 @@ class Agent(Insight, Channel, Catalog, Dataset):
             filters = []
 
         if(dataset_id=="" and dataset_slug!=""):
-            datasetId = self.get_dataset_by_slug(self._agentId, dataset_slug)["id"]
+            s = requests.Session()
+            s.keep_alive = False
+            retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+            s.mount('https://', HTTPAdapter(max_retries=retries))
+
+            url = self._base_url_askdata + '/smartbot/agents/agentslug/' + self.slug + '/datasetslug/' + dataset_slug
+            logging.info("URL {}".format(url))
+
+            headers = {"Authorization": "Bearer" + " " + self._token}
+            response = s.get(url=url, headers=headers)
+            response.raise_for_status()
+            r = response.json()
+
+            datasetId = r["datasetId"]
+
         elif(dataset_id!=""):
             datasetId=dataset_id
         else:
@@ -392,13 +406,13 @@ class Agent(Insight, Channel, Catalog, Dataset):
         r = response.json()
         return pd.DataFrame(r['data'])
 
-    def get_dataset_by_slug(self, agent_id, slug: str) -> Dataset:
+    def get_dataset_by_slug(self, agent_slug, slug: str) -> Dataset:
         s = requests.Session()
         s.keep_alive = False
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
         s.mount('https://', HTTPAdapter(max_retries=retries))
 
-        authentication_url = self._base_url_askdata + '/smartdataset/datasets/slug/' + agent_id + '/' + slug
+        authentication_url = self._base_url_askdata + '/smartbot/agents/agentslug/'+ agent_slug +'/datasetslug/' + slug
         logging.info("AUTH URL {}".format(authentication_url))
 
         headers = {"Authorization": "Bearer" + " " + self._token}
@@ -575,7 +589,7 @@ class Agent(Insight, Channel, Catalog, Dataset):
     def create_or_replace_dataset(self, dataframe: pd.DataFrame, dataset_name: str, slug: str, icon_url=None,
                                   settings: dict = None):
         # Check if dataset exists
-        dataset = self.get_dataset_by_slug(self._agentId, slug)
+        dataset = self.get_dataset_by_slug(self.slug, slug)
 
         dataframe = dataframe.where(pd.notnull(dataframe), None)
         if(dataset != None):
@@ -804,6 +818,18 @@ class Askdata(SignUp):
         # Agent.__init__(self, self, slug=slug)
         return Agent(self, slug=slug, agent_id=agent_id)
 
+
+    def get(self, query, workspace, dataset, lang="en"):
+        if self._env == 'dev':
+            base_url = url_list['BASE_URL_INSIGHT_DEV']
+        elif self._env == 'qa':
+            base_url = url_list['BASE_URL_INSIGHT_QA']
+        elif self._env == 'prod':
+            base_url = url_list['BASE_URL_INSIGHT_PROD']
+
+        url = base_url + "/data/nl/result"
+
+
     def load_agents(self):
 
         if self._env == 'dev':
